@@ -28,20 +28,24 @@
 #include <QDirIterator>
 #include <QFile>
 #include <QFileInfo>
-#include <QScriptValue>
-#include <QScriptContext>
 #include <QTextStream>
-#include <QWebView>
-#include <QWebFrame>
 #include <QDialog>
+#include <QUrl>
 
 #include "processes.h"
 #include "ksysguardprocesslist.h"
 
-#include <KMessageBox>
 #include <KDesktopFile>
 #include <KStandardAction>
+#include <KLocalizedString>
 #include <QVBoxLayout>
+#include <QMessageBox>
+#include <QDialogButtonBox>
+
+#if HAVE_QTWEBKITWIDGETS
+#include <QWebView>
+#include <QWebFrame>
+#endif
 
 class ScriptingHtmlDialog : public QDialog {
     public:
@@ -49,9 +53,10 @@ class ScriptingHtmlDialog : public QDialog {
 
             QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
             buttonBox->setStandardButtons(QDialogButtonBox::Close);
-            connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-            connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+            connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+            connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
+#if HAVE_QTWEBKITWIDGETS
             QVBoxLayout *layout = new QVBoxLayout;
             layout->addWidget(&m_webView);
             layout->addWidget(buttonBox);
@@ -65,12 +70,31 @@ class ScriptingHtmlDialog : public QDialog {
             m_webView.page()->setNetworkAccessManager(NULL); //Disable talking to remote servers
             m_webView.page()->mainFrame()->setScrollBarPolicy(Qt::Horizontal, Qt::ScrollBarAsNeeded);
             m_webView.page()->mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAsNeeded);
+
+            // inject a style sheet that follows system colors, otherwise we might end up with black text on dark gray background
+            const QString styleSheet = QStringLiteral(
+                "body { background: %1; color: %2; }" \
+                "a { color: %3; }" \
+                "a:visited { color: %4; } "
+            ).arg(palette().background().color().name(),
+                  palette().text().color().name(),
+                  palette().link().color().name(),
+                  palette().linkVisited().color().name());
+
+            // you can only provide a user style sheet url, so we turn it into a data url here
+            const QUrl dataUrl(QStringLiteral("data:text/css;charset=utf-8;base64,") + QString::fromLatin1(styleSheet.toUtf8().toBase64()));
+
+            m_webView.settings()->setUserStyleSheetUrl(dataUrl);
+
+#endif
         }
+#if HAVE_QTWEBKITWIDGETS
         QWebView *webView() {
             return &m_webView;
         }
     protected:
         QWebView m_webView;
+#endif
 };
 
 ProcessObject::ProcessObject(ProcessModel *model, int pid) {
@@ -103,14 +127,15 @@ void Scripting::runScript(const QString &path, const QString &name) {
     mScriptPath = path;
     mScriptName = name;
 
+#if HAVE_QTWEBKITWIDGETS
     QUrl fileName = QUrl::fromLocalFile(path + "index.html");
     if(!mScriptingHtmlDialog) {
         mScriptingHtmlDialog = new ScriptingHtmlDialog(this);
-        connect(mScriptingHtmlDialog, SIGNAL(rejected()), SLOT(stopAllScripts()));
+        connect(mScriptingHtmlDialog, &QDialog::rejected, this, &Scripting::stopAllScripts);
 
-        QAction *refreshAction = new QAction("refresh", mScriptingHtmlDialog);
+        QAction *refreshAction = new QAction(QStringLiteral("refresh"), mScriptingHtmlDialog);
         refreshAction->setShortcut(QKeySequence::Refresh);
-        connect(refreshAction, SIGNAL(triggered()), SLOT(refreshScript()));
+        connect(refreshAction, &QAction::triggered, this, &Scripting::refreshScript);
         mScriptingHtmlDialog->addAction(refreshAction);
 
         QAction *zoomInAction = KStandardAction::zoomIn(this, SLOT(zoomIn()), mScriptingHtmlDialog);
@@ -123,11 +148,14 @@ void Scripting::runScript(const QString &path, const QString &name) {
     //Make the process information available to the script
     mScriptingHtmlDialog->webView()->load(fileName);
     mScriptingHtmlDialog->show();
-    connect(mScriptingHtmlDialog->webView()->page()->mainFrame(), SIGNAL(javaScriptWindowObjectCleared()), SLOT(setupJavascriptObjects()));
+    connect(mScriptingHtmlDialog->webView()->page()->mainFrame(), &QWebFrame::javaScriptWindowObjectCleared, this, &Scripting::setupJavascriptObjects);
     setupJavascriptObjects();
-
-//    connect(mProcessList, SIGNAL(updated()), SLOT(refreshScript()));
+#else
+    QMessageBox::critical(this, i18n("QtWebKitWidgets not available"),
+            i18n("KSysGuard library was compiled without QtWebKitWidgets, please contact your distribution."));
+#endif
 }
+#if HAVE_QTWEBKITWIDGETS
 void Scripting::zoomIn() {
     QWebView *webView = mScriptingHtmlDialog->webView();
     webView->setZoomFactor( webView->zoomFactor() * 1.1 );
@@ -142,14 +170,15 @@ void Scripting::refreshScript() {
     //Call any refresh function, if it exists
     mProcessList->processModel()->update(0, KSysGuard::Processes::XMemory);
     if(mScriptingHtmlDialog && mScriptingHtmlDialog->webView() && mScriptingHtmlDialog->webView()->page() && mScriptingHtmlDialog->webView()->page()->mainFrame()) {
-        mScriptingHtmlDialog->webView()->page()->mainFrame()->evaluateJavaScript("refresh();");
+        mScriptingHtmlDialog->webView()->page()->mainFrame()->evaluateJavaScript(QStringLiteral("refresh();"));
     }
 }
 void Scripting::setupJavascriptObjects() {
     mProcessList->processModel()->update(0, KSysGuard::Processes::XMemory);
     mProcessObject = new ProcessObject(mProcessList->processModel(), mPid);
-    mScriptingHtmlDialog->webView()->page()->mainFrame()->addToJavaScriptWindowObject("process", mProcessObject, QWebFrame::ScriptOwnership);
+    mScriptingHtmlDialog->webView()->page()->mainFrame()->addToJavaScriptWindowObject(QStringLiteral("process"), mProcessObject, QWebFrame::ScriptOwnership);
 }
+#endif
 void Scripting::stopAllScripts()
 {
     if (mScriptingHtmlDialog)
@@ -165,7 +194,7 @@ void Scripting::loadContextMenu() {
     mActions.clear();
 
     QStringList scripts;
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "ksysguard/scripts/", QStandardPaths::LocateDirectory);
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("ksysguard/scripts/"), QStandardPaths::LocateDirectory);
     Q_FOREACH (const QString& dir, dirs) {
         QDirIterator it(dir, QStringList() << QStringLiteral("*.desktop"), QDir::NoFilter, QDirIterator::Subdirectories);
         while (it.hasNext()) {
@@ -182,7 +211,7 @@ void Scripting::loadContextMenu() {
             QString scriptPath = script;
             scriptPath.truncate(scriptPath.lastIndexOf('/'));
             action->setProperty("scriptPath", QString(scriptPath + QLatin1Char('/')));
-            connect(action, SIGNAL(triggered(bool)), SLOT(runScriptSlot()));
+            connect(action, &QAction::triggered, this, &Scripting::runScriptSlot);
             mProcessList->addAction(action);
             mActions << action;
         }
